nbxmpp.idlequeue

Package nbxmpp :: Module idlequeue |
[hide private]
[frames] | no frames]

# Module idlequeue

source code

Idlequeues are Gajim's network heartbeat. Transports can be plugged as idle objects and be informed about possible IO

Classes | [hide private]
| IdleObject Idle listener interface. Listed methods are called by IdleQueue.
| IdleCommand Can be subclassed to execute commands asynchronously by the idlequeue. Result will be optained via file descriptor of created pipe
| IdleQueue IdleQueue provide three distinct time based features. Uses select.poll()
| SelectIdleQueue Extends IdleQueue to use select.select() for polling
| GlibIdleQueue Extends IdleQueue to use glib io_add_wath, instead of select/poll In another 'non gui' implementation of Gajim IdleQueue can be used safetly

Functions | [hide private]
get_idlequeue() Get an appropriate idlequeue | source code

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.idlequeue')`
| HAVE_GOBJECT = `True`
| FLAG_WRITE = `20`
| FLAG_READ = `19`
| FLAG_READ_WRITE = `23`
| FLAG_CLOSE = `16`
| PENDING_READ = `3`
| PENDING_WRITE = `4`
| IS_CLOSED = `16`
| __package__ = ``'``nbxmpp``'``

Imports: os, select, logging, gobject, STDOUT, PIPE, call, CalledProcessError, Popen, check_call, check_output, fcntl

Function Details | [hide private]

### get_idlequeue() | source code
Get an appropriate idlequeue

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.idlequeue')

  ### HAVE_GOBJECT Value:
      True

  ### FLAG_WRITE Value:
      20

  ### FLAG_READ Value:
      19

  ### FLAG_READ_WRITE Value:
      23

  ### FLAG_CLOSE Value:
      16

  ### PENDING_READ Value:
      3

  ### PENDING_WRITE Value:
      4

  ### IS_CLOSED Value:
      16

  ### __package__ Value:
      'nbxmpp'